==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/ExponentialBucketsDefinitionFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ExponentialBucketsDefinitionFluentImpl<A extends ExponentialBucketsDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ExponentialBucketsDefinitionFluent<A>{

    private ExponentialBuilder exponentialBuckets;

    public ExponentialBucketsDefinitionFluentImpl(){
    }
    public ExponentialBucketsDefinitionFluentImpl(ExponentialBucketsDefinition instance){
            this.withExponentialBuckets(instance.getExponentialBuckets()); 
    }

    
/**
 * This method has been deprecated, please use method buildExponentialBuckets instead.
 * @return The buildable object.
 */
@Deprecated public Exponential getExponentialBuckets(){
            return this.exponentialBuckets!=null?this.exponentialBuckets.build():null;
    }

    public Exponential buildExponentialBuckets(){
            return this.exponentialBuckets!=null?this.exponentialBuckets.build():null;
    }

    public A withExponentialBuckets(Exponential exponentialBuckets){
            _visitables.remove(this.exponentialBuckets);
            if (exponentialBuckets!=null){ this.exponentialBuckets= new ExponentialBuilder(exponentialBuckets); _visitables.add(this.exponentialBuckets);} return (A) this;
    }

    public Boolean hasExponentialBuckets(){
            return this.exponentialBuckets != null;
    }

    public A withNewExponentialBuckets(Double growthFactor,Integer numFiniteBuckets,Double scale){
            return (A)withExponentialBuckets(new Exponential(growthFactor, numFiniteBuckets, scale));
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> withNewExponentialBuckets(){
            return new ExponentialBucketsNestedImpl();
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> withNewExponentialBucketsLike(Exponential item){
            return new ExponentialBucketsNestedImpl(item);
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> editExponentialBuckets(){
            return withNewExponentialBucketsLike(getExponentialBuckets());
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> editOrNewExponentialBuckets(){
            return withNewExponentialBucketsLike(getExponentialBuckets() != null ? getExponentialBuckets(): new ExponentialBuilder().build());
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> editOrNewExponentialBucketsLike(Exponential item){
            return withNewExponentialBucketsLike(getExponentialBuckets() != null ? getExponentialBuckets(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExponentialBucketsDefinitionFluentImpl that = (ExponentialBucketsDefinitionFluentImpl) o;
            if (exponentialBuckets != null ? !exponentialBuckets.equals(that.exponentialBuckets) :that.exponentialBuckets != null) return false;
            return true;
    }


    public class ExponentialBucketsNestedImpl<N> extends ExponentialFluentImpl<ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<N>> implements ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ExponentialBuilder builder;
    
            ExponentialBucketsNestedImpl(Exponential item){
                    this.builder = new ExponentialBuilder(this, item);
            }
            ExponentialBucketsNestedImpl(){
                    this.builder = new ExponentialBuilder(this);
            }
    
    public N and(){
            return (N) ExponentialBucketsDefinitionFluentImpl.this.withExponentialBuckets(builder.build());
    }
    public N endExponentialBuckets(){
            return and();
    }

}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/ExponentialBucketsDefinitionFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ExponentialBucketsDefinitionFluentImpl<A extends ExponentialBucketsDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ExponentialBucketsDefinitionFluent<A>{

    private ExponentialBuilder exponentialBuckets;

    public ExponentialBucketsDefinitionFluentImpl(){
    }
    public ExponentialBucketsDefinitionFluentImpl(ExponentialBucketsDefinition instance){
            this.withExponentialBuckets(instance.getExponentialBuckets()); 
    }

    
/**
 * This method has been deprecated, please use method buildExponentialBuckets instead.
 * @return The buildable object.
 */
@Deprecated public Exponential getExponentialBuckets(){
            return this.exponentialBuckets!=null?this.exponentialBuckets.build():null;
    }

    public Exponential buildExponentialBuckets(){
            return this.exponentialBuckets!=null?this.exponentialBuckets.build():null;
    }

    public A withExponentialBuckets(Exponential exponentialBuckets){
            _visitables.get("exponentialBuckets").remove(this.exponentialBuckets);
            if (exponentialBuckets!=null){ this.exponentialBuckets= new ExponentialBuilder(exponentialBuckets); _visitables.get("exponentialBuckets").add(this.exponentialBuckets);} return (A) this;
    }

    public Boolean hasExponentialBuckets(){
            return this.exponentialBuckets != null;
    }

    public A withNewExponentialBuckets(Double growthFactor,Integer numFiniteBuckets,Double scale){
            return (A)withExponentialBuckets(new Exponential(growthFactor, numFiniteBuckets, scale));
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> withNewExponentialBuckets(){
            return new ExponentialBucketsNestedImpl();
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> withNewExponentialBucketsLike(Exponential item){
            return new ExponentialBucketsNestedImpl(item);
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> editExponentialBuckets(){
            return withNewExponentialBucketsLike(getExponentialBuckets());
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> editOrNewExponentialBuckets(){
            return withNewExponentialBucketsLike(getExponentialBuckets() != null ? getExponentialBuckets(): new ExponentialBuilder().build());
    }

    public ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<A> editOrNewExponentialBucketsLike(Exponential item){
            return withNewExponentialBucketsLike(getExponentialBuckets() != null ? getExponentialBuckets(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ExponentialBucketsDefinitionFluentImpl that = (ExponentialBucketsDefinitionFluentImpl) o;
            if (exponentialBuckets != null ? !exponentialBuckets.equals(that.exponentialBuckets) :that.exponentialBuckets != null) return false;
            return true;
    }


    public class ExponentialBucketsNestedImpl<N> extends ExponentialFluentImpl<ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<N>> implements ExponentialBucketsDefinitionFluent.ExponentialBucketsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ExponentialBuilder builder;
    
            ExponentialBucketsNestedImpl(Exponential item){
                    this.builder = new ExponentialBuilder(this, item);
            }
            ExponentialBucketsNestedImpl(){
                    this.builder = new ExponentialBuilder(this);
            }
    
    public N and(){
            return (N) ExponentialBucketsDefinitionFluentImpl.this.withExponentialBuckets(builder.build());
    }
    public N endExponentialBuckets(){
            return and();
    }

}


}
